@@ -1,11 +1,9 @@
 # env.rb -- snd/env.scm
 
 # Translator/Author: Michael Scholz <mi-scholz@users.sourceforge.net>
-# Created: Sat Sep 20 23:24:17 CEST 2003
-# Changed: Mon Dec 14 16:08:26 CET 2009
+# Created: 03/09/20 23:24:17
+# Changed: 14/11/13 04:52:42
 
-# Commentary:
-#
 # module Env (see env.scm)
 #  envelope_interp(x, en, base)
 #  window_envelope(beg, dur, en)
@@ -20,7 +18,7 @@
 #  scale_envelope(en, scale, offset)
 #  reverse_envelope(en)              alias envelope_reverse
 #  concatenate_envelopes(*envs)      alias envelope_concatenate
-#  repeat_envelope(ur_env, repeats, reflect, x_normalized)   alias envelope_repeat
+#  repeat_envelope(ur_env, repeats, reflect, x_normalized) alias envelope_repeat
 #
 #  class Power_env
 #   initialize(*rest)
@@ -39,7 +37,8 @@
 #  normalize_envelope(en, new_max)
 #  x_norm(en, xmax)
 #
-#  exp_envelope(env, *args) [by Fernando Lopez-Lezcano (nando@ccrma.stanford.edu)]
+#  exp_envelope(env, *args)
+#    [by Fernando Lopez-Lezcano (nando@ccrma.stanford.edu)]
 #    db_envelope(env, cutoff, error)
 #    make_db_env(env, *args)
 #    semitones_envelope(env, around, error)
@@ -47,17 +46,20 @@
 #    octaves_envelope(env, around, error)
 #    make_octaves_env(env, *args)
 
-# Code:
-
 require "clm"
 
 module Env
   add_help(:envelope_interp,
            "envelope_interp(*args)
-envelope_interp(x, env, base = 1.0) -> value of env at x; \
-base controls connecting segment type: envelope_interp(0.3, [0, 0, 0.5, 1, 1, 0]) -> 0.6")
+envelope_interp(x, env, base = 1.0) ==> value of env at x;  \
+BASE controls connecting segment type: \
+envelope_interp(0.3, [0, 0, 0.5, 1, 1, 0]) ==> 0.6")
   def envelope_interp(x, en, base = 1.0)
-    en.map! do |y| y.to_f end unless en.empty?
+    unless en.empty?
+      en.map! do |y|
+        y.to_f
+      end
+    end
     if en.empty?
       0.0
     else
@@ -86,11 +88,15 @@ base controls connecting segment type: envelope_interp(0.3, [0, 0, 0.5, 1, 1, 0]
   end
 
   add_help(:window_envelope,
-           "window_envelope(beg, dur, env) \
-portion of env lying between x axis values beg and end: \
-window_envelope(1.0, 3.0, [0.0, 0.0, 5.0, 1.0]) -> [1.0, 0.2, 3.0, 0.6]")
+           "window_envelope(beg, dur, env)  \
+Portion of ENV lying between x axis values BEG and DUR: \
+window_envelope(1.0, 3.0, [0.0, 0.0, 5.0, 1.0]) ==> [1.0, 0.2, 3.0, 0.6]")
   def window_envelope(beg, dur, en)
-    en.map! do |x| x.to_f end unless en.empty?
+    unless en.empty?
+      en.map! do |x|
+        x.to_f
+      end
+    end
     nenv = []
     lasty = en.empty? ? 0.0 : en[1]
     len = en.length
@@ -124,10 +130,18 @@ window_envelope(1.0, 3.0, [0.0, 0.0, 5.0, 1.0]) -> [1.0, 0.2, 3.0, 0.6]")
 
   add_help(:map_envelopes,
            "map_envelopes(env1, env2, &func)  \
-maps func over the breakpoints in env1 and env2 returning a new envelope")
+Maps FUNC over the breakpoints in ENV1 and ENV2 returning a new envelope.")
   def map_envelopes(en1, en2, &func)
-    en1.map! do |x| x.to_f end unless en1.empty?
-    en2.map! do |x| x.to_f end if array?(en2) and (not en2.empty?)
+    unless en1.empty?
+      en1.map! do |x|
+        x.to_f
+      end
+    end
+    if array?(en2) and (not en2.empty?)
+      en2.map! do |x|
+        x.to_f
+      end
+    end
     xs = []
     at0 = lambda do |e|
       diff = e.first
@@ -149,7 +163,8 @@ maps func over the breakpoints in env1 and env2 returning a new envelope")
         ee2 = at0.call(en2)
         newe = []
         xs.uniq.sort.each do |x|
-          newe.push(x, func.call(envelope_interp(x, ee1), envelope_interp(x, ee2)))
+          newe.push(x,
+                    func.call(envelope_interp(x, ee1), envelope_interp(x, ee2)))
         end
         newe
       end
@@ -158,76 +173,107 @@ maps func over the breakpoints in env1 and env2 returning a new envelope")
 
   add_help(:multiply_envelopes,
            "multiply_envelopes(env1, env2)  \
-multiplies break-points of env1 and env2 returning a new envelope: \
-multiply_envelopes([0, 0, 2, 0.5], [0, 0, 1, 2, 2, 1]) -> [0.0, 0.0, 0.5, 0.5, 1.0, 0.5]")
+Multiplies break-points of ENV1 and ENV2 returning a new envelope: \
+multiply_envelopes([0, 0, 2, 0.5], [0, 0, 1, 2, 2, 1]) ==> \
+[0.0, 0.0, 0.5, 0.5, 1.0, 0.5]")
   def multiply_envelopes(en1, en2)
-    map_envelopes(en1, en2) do |x, y| x * y end
+    map_envelopes(en1, en2) do |x, y|
+      x * y
+    end
   end
 
   add_help(:add_envelopes,
-           "add_envelopes(env1, env2) adds break-points of env1 and env2 returning a new envelope")
+           "add_envelopes(env1, env2)  \
+Adds break-points of ENV1 and ENV2 returning a new envelope.")
   def add_envelopes(en1, en2)
-    map_envelopes(en1, en2) do |x, y| x + y end
+    map_envelopes(en1, en2) do |x, y|
+      x + y
+    end
   end
 
-  add_help(:max_envelope, "max_envelope(env) -> max y value in env")
+  add_help(:max_envelope,
+           "max_envelope(env)  \
+Returns max y value in ENV.")
   def max_envelope(en)
     mx = en[1].to_f
-    1.step(en.length - 1, 2) do |i| mx = [mx, en[i]].max.to_f end
+    1.step(en.length - 1, 2) do |i|
+      mx = [mx, en[i]].max.to_f
+    end
     mx
   end
   
-  add_help(:min_envelope, "min_envelope(env) -> min y value in env")
+  add_help(:min_envelope,
+           "min_envelope(env)  \
+Returns min y value in ENV.")
   def min_envelope(en)
     mn = en[1].to_f
-    1.step(en.length - 1, 2) do |i| mn = [mn, en[i]].min.to_f end
+    1.step(en.length - 1, 2) do |i|
+      mn = [mn, en[i]].min.to_f
+    end
     mn
   end
 
-  add_help(:integrate_envelope, "integrate_envelope(env) -> area under env")
+  add_help(:integrate_envelope,
+           "integrate_envelope(env)  \
+Returns area under ENV.")
   def integrate_envelope(en)
     sum = 0.0
-    0.step(en.length - 3, 2) do |i| sum += (en[i + 1] + en[i + 3]) * (en[i + 2] - en[i]) * 0.5 end
+    0.step(en.length - 3, 2) do |i|
+      sum = sum + (en[i + 1] + en[i + 3]) * (en[i + 2] - en[i]) * 0.5
+    end
     sum
   end
 
-  add_help(:envelope_last_x, "envelope_last_x(env) -> max x axis break point position")
+  add_help(:envelope_last_x,
+           "envelope_last_x(env)  \
+Returns max x axis break point position.")
   def envelope_last_x(en)
     en.empty? ? 0.0 : en[-2]
   end
   
   add_help(:stretch_envelope,
            "stretch_envelope(fn, old_att, new_att, old_dec, new_dec)  \
-takes FN and returns a new envelope based on it but with the attack \
+Takes FN and returns a new envelope based on it but with the attack \
 and optionally decay portions stretched or squeezed; \
 OLD_ATT is the original x axis attack end point, \
 NEW_ATT is where that section should end in the new envelope.  \
 Similarly for OLD_DEC and NEW_DEC.  \
-This mimics divseg in early versions of CLM and its antecedents in Sambox and Mus10 (linen).
-stretch_envelope([0, 0, 1, 1], 0.1, 0.2) -> [0, 0, 0.2, 0.1, 1.0, 1]
+This mimics divseg in early versions of CLM \
+and its antecedents in Sambox and Mus10 (linen).
+stretch_envelope([0, 0, 1, 1], 0.1, 0.2) ==> [0, 0, 0.2, 0.1, 1.0, 1]
 stretch_envelope([0, 0, 1, 1, 2, 0], 0.1, 0.2, 1.5, 1.6)
-                 -> [0, 0, 0.2, 0.1, 1.1, 1, 1.6, 0.5, 2.0, 0]")
-  def stretch_envelope(fn, old_att = false, new_att = false, old_dec = false, new_dec = false)
+==> [0, 0, 0.2, 0.1, 1.1, 1, 1.6, 0.5, 2.0, 0]")
+  def stretch_envelope(fn, old_att = false, new_att = false,
+                       old_dec = false, new_dec = false)
     unless array?(fn)
       error("%s: need an envelope, %s", get_func_name, fn.inspect)
     end
-    fn.map! do |x| x.to_f end unless fn.empty?
+    unless fn.empty?
+      fn.map! do |x|
+        x.to_f
+      end
+    end
     if old_att and (not new_att)
-      Snd.raise(:wrong_number_of_args, old_att.inspect, "old_att but no new_att?")
+      Snd.raise(:wrong_number_of_args,
+                old_att.inspect,
+                "old_att but no new_att?")
     else
       if (not new_att)
         fn
       else
         if old_dec and (not new_dec)
           Snd.raise(:wrong_number_of_args,
-                    format("%s %s %s", old_att, new_att, old_dec), "old_dec but no new_dec?")
+                    format("%s %s %s", old_att, new_att, old_dec),
+                    "old_dec but no new_dec?")
         else
           new_x = x0 = fn[0]
           last_x = fn[-2]
           y0 = fn[1]
           new_fn = [x0, y0]
           scl = (new_att - x0) / [0.0001, old_att - x0].max
-          old_dec += 0.000001 * last_x if old_dec and old_dec == old_att
+          if old_dec and old_dec == old_att
+            old_dec = old_dec + 0.000001 * last_x
+          end
           fn[2..-1].each_pair do |x1, y1|
             if x0 < old_att and x1 >= old_att
               y0 = if x1 == old_att
@@ -256,7 +302,7 @@ stretch_envelope([0, 0, 1, 1, 2, 0], 0.1, 0.2, 1.5, 1.6)
               scl = (last_x - new_dec) / (last_x - old_dec)
             end
             if x0 != x1
-              new_x += scl * (x1 - x0)
+              new_x = new_x + scl * (x1 - x0)
               new_fn.push(new_x, y1)
               x0, y0 = x1, y1
             end
@@ -268,14 +314,18 @@ stretch_envelope([0, 0, 1, 1, 2, 0], 0.1, 0.2, 1.5, 1.6)
   end
 
   add_help(:scale_envelope,
-           "scale_envelope(env, scale, offset = 0.0) \
-scales y axis values by SCALER and optionally adds OFFSET")
+           "scale_envelope(env, scale, offset = 0.0)  \
+Scales y axis values by SCALER and optionally adds OFFSET.")
   def scale_envelope(en, scale, offset = 0.0)
-    1.step(en.length - 1, 2) do |i| en[i] = en[i] * scale + offset end
+    1.step(en.length - 1, 2) do |i|
+      en[i] = en[i] * scale + offset
+    end
     en
   end
 
-  add_help(:reverse_envelope, "reverse_envelope(env) reverses the breakpoints in ENV")
+  add_help(:reverse_envelope,
+           "reverse_envelope(env)  \
+Reverses the breakpoints in ENV.")
   def reverse_envelope(en1)
     len = en1.length
     if len.zero? or len == 2
@@ -292,7 +342,8 @@ scales y axis values by SCALER and optionally adds OFFSET")
   alias envelope_reverse reverse_envelope
 
   add_help(:concatenate_envelopes,
-           "concatenate_envelopes(*envs) concatenates its arguments into a new envelope")
+           "concatenate_envelopes(*envs)  \
+Concatenates its arguments into a new envelope.")
   def concatenate_envelopes(*envs)
     if envs.length == 1
       envs.first
@@ -300,13 +351,17 @@ scales y axis values by SCALER and optionally adds OFFSET")
       xoff = 0.0
       ren = []
       envs.each do |en|
-        (en or []).map! do |x| x.to_f end
+        (en or []).map! do |x|
+          x.to_f
+        end
         firstx = en.first
         if ren[-1] == en[1]
           xoff -= 0.01
           en = en[2..-1]
         end
-        0.step(en.length - 1, 2) do |i| ren.push(xoff + (en[i] - firstx), en[i + 1]) end
+        0.step(en.length - 1, 2) do |i|
+          ren.push(xoff + (en[i] - firstx), en[i + 1])
+        end
         xoff += 0.01 + ren[-2]
       end
       ren
@@ -315,15 +370,19 @@ scales y axis values by SCALER and optionally adds OFFSET")
   alias envelope_concatenate concatenate_envelopes
 
   add_help(:repeat_envelope,
-           "repeat_envelope(ur_env, repeats, reflected = false, x_normalized = false) \
-repeats ENV REPEATS times.
-repeat_envelope([0, 0, 100, 1] 2) -> [0, 0, 100, 1, 101, 0, 201, 1]
+           "repeat_envelope(ur_env, repeats, reflected = false, \
+x_normalized = false)  \
+Repeats ENV REPEATS times.
+repeat_envelope([0, 0, 100, 1] 2) ==> [0, 0, 100, 1, 101, 0, 201, 1]
 If the final y value is different from the first y value, \
 a quick ramp is inserted between repeats. \
-X_NORMALIZED causes the new envelope's x axis to have the same extent as the original's. \
+X_NORMALIZED causes the new envelope's x axis \
+to have the same extent as the original's. \
 REFLECTED causes every other repetition to be in reverse.")
   def repeat_envelope(ur_env, repeats, reflected = false, x_normalized = false)
-    (ur_env or []).map! do |x| x.to_f end
+    (ur_env or []).map! do |x|
+      x.to_f
+    end
     tms = (reflected ? (repeats / 2).floor : repeats)
     en = if reflected
            lastx = ur_env[-2]
@@ -336,7 +395,9 @@ REFLECTED causes every other repetition to be in reverse.")
          else
            ur_env
          end
-    (en or []).map! do |x| x.to_f end
+    (en or []).map! do |x|
+      x.to_f
+    end
     first_y = en[1]
     x_max = en[-2]
     x = en.first
@@ -349,13 +410,15 @@ REFLECTED causes every other repetition to be in reverse.")
         new_env.push(x, en[j + 1])
       end
       if (i < tms - 1) and (not first_y_is_last_y)
-        x += x_max / 100.0
+        x = x + x_max / 100.0
         new_env.push(x, first_y)
       end
     end
     if x_normalized
       scl = x_max / x
-      0.step(new_env.length - 1, 2) do |i| new_env[i] *= scl end
+      0.step(new_env.length - 1, 2) do |i|
+        new_env[i] *= scl
+      end
     end
     new_env
   end
@@ -369,7 +432,9 @@ REFLECTED causes every other repetition to be in reverse.")
              [:scaler, 1.0],
              [:offset, 0.0],
              [:duration, 0.0])
-      envelope.map! do |val| Float(val) end
+      envelope.map! do |val|
+        Float(val)
+      end
       xext = envelope[-3] - envelope.first
       j = 0
       @envs = make_array(envelope.length / 3 - 1) do |i|
@@ -420,13 +485,15 @@ REFLECTED causes every other repetition to be in reverse.")
     pe.power_env
   end
 
-  def power_env_channel(pe, beg = 0, dur = false, snd = false, chn = false, edpos = false)
+  def power_env_channel(pe, beg = 0, dur = false,
+                        snd = false, chn = false, edpos = false)
     pe.power_env_channel(beg, dur, snd, chn, edpos, get_func_name)
   end
 
-  def powenv_channel(envelope, beg = 0, dur = false, snd = false, chn = false, edpos = false)
+  def powenv_channel(envelope, beg = 0, dur = false,
+                     snd = false, chn = false, edpos = false)
     curbeg = beg
-    fulldur = (dur or frames(snd, chn, edpos))
+    fulldur = (dur or framples(snd, chn, edpos))
     len = envelope.length
     x1 = envelope[0]
     xrange = envelope[len - 3] - x1
@@ -461,7 +528,11 @@ REFLECTED causes every other repetition to be in reverse.")
   # xgrid is how fine a solution to sample our new envelope with.
 
   def envelope_exp(en, power = 1.0, xgrid = 100)
-    en.map! do |x| x.to_f end unless en.empty?
+    unless en.empty?
+      en.map! do |x|
+        x.to_f
+      end
+    end
     mn = min_envelope(en)
     largest_diff = max_envelope(en) - mn
     x_min = en.first
@@ -470,9 +541,10 @@ REFLECTED causes every other repetition to be in reverse.")
     new_en = []
     x_min.step(x_max, x_incr) do |x|
       y = envelope_interp(x, en)
-      new_en.push(x, (largest_diff.zero? ?
-                      y :
-                         (mn + largest_diff * (((y - mn) / largest_diff) ** power))))
+      new_en.push(x,
+                  (largest_diff.zero? ?
+                    y :
+                    (mn + largest_diff * (((y - mn) / largest_diff) ** power))))
     end
     new_en
   end
@@ -490,7 +562,9 @@ REFLECTED causes every other repetition to be in reverse.")
     incrsamps = (incr * sfr).round
     start = (beg * fsr).round
     reader = make_sampler(start, file)
-    fin = dur ? [start + (fsr * dur).round, mus_sound_frames(file)].min : mus_sound_frames(file)
+    fin = dur ?
+            [start + (fsr * dur).round, mus_sound_framples(file)].min :
+            mus_sound_framples(file)
     rms = make_moving_average(incrsamps)
     0.step(fin, incrsamps) do |i|
       rms_val = 0.0
@@ -518,18 +592,22 @@ REFLECTED causes every other repetition to be in reverse.")
 
   def normalize_envelope(en, new_max = 1.0)
     mx = en[1].abs.to_f
-    1.step(en.length - 1, 2) do |i| mx = [mx, en[i].abs].max.to_f end
+    1.step(en.length - 1, 2) do |i|
+      mx = [mx, en[i].abs].max.to_f
+    end
     scale_envelope(en, new_max / mx)
   end
   
   def x_norm(en, xmax)
     scl = xmax / en[-2].to_f
-    en.each_pair do |x, y| [x * scl, y.to_f] end.flatten
+    en.each_pair do |x, y|
+      [x * scl, y.to_f]
+    end.flatten
   end
 
-  # ;;;=============================================================================
+  # ;;;=======================================================================
   # ;;; Exponential envelopes
-  # ;;;=============================================================================
+  # ;;;=======================================================================
   # 
   # ;;; Approximate an exponential envelope with a given base and error bound
   # ;;; by Fernando Lopez-Lezcano (nando@ccrma.stanford.edu)
@@ -585,8 +663,10 @@ REFLECTED causes every other repetition to be in reverse.")
       yscl  = offset + y  * scaler
       nyscl = offset + ny * scaler
       result.push(x)
-      result.push((((not ycutoff) or base ** yscl >= ycutoff) ? (out_scaler * base ** yscl) : 0.0))
-      xs, ys = exp_seg.call(x, base ** yscl, nx, base ** nyscl, yscl, nyscl, error)
+      result.push((((not ycutoff) or base ** yscl >= ycutoff) ?
+                  (out_scaler * base ** yscl) : 0.0))
+      xs, ys = exp_seg.call(x, base ** yscl,
+                            nx, base ** nyscl, yscl, nyscl, error)
       unless xs.empty?
         ys_scaled = vct_scale!(list2vct(ys), out_scaler)
         xs.each_with_index do |xx, ii|
@@ -596,7 +676,8 @@ REFLECTED causes every other repetition to be in reverse.")
       end
     end
     result.push(nx)
-    result.push((((not ycutoff) or base ** nyscl >= ycutoff) ? (out_scaler * base ** nyscl) : 0.0))
+    result.push((((not ycutoff) or base ** nyscl >= ycutoff) ?
+                (out_scaler * base ** nyscl) : 0.0))
   end
 
   # ;;; Amplitude envelope in dBs
@@ -606,7 +687,8 @@ REFLECTED causes every other repetition to be in reverse.")
   # ;;;  where:
   # ;;;    vref=1.0 reference value = digital clipping
   def db_envelope(env, cutoff = -70, error = 0.01)
-    exp_envelope(env, :base, 10.0, :scaler, 1.0 / 20, :cutoff, cutoff, :error, error)
+    exp_envelope(env, :base, 10.0, :scaler, 1.0 / 20,
+                 :cutoff, cutoff, :error, error)
   end
 
   def make_db_env(env, *args)
@@ -619,8 +701,8 @@ REFLECTED causes every other repetition to be in reverse.")
            [:len, 0],
            [:cutoff, -70],
            [:error, 0.01])
-    make_env(:envelope, db_envelope(env, cutoff, error), :scaler, scaler, :offset, offset,
-             :base, base, :duration, dur, :length, len)
+    make_env(:envelope, db_envelope(env, cutoff, error), :scaler, scaler,
+             :offset, offset, :base, base, :duration, duration, :length, len)
   end
 
   # ;;; Pitch envelopes (y units are semitone and octave intervals)
@@ -638,7 +720,8 @@ REFLECTED causes every other repetition to be in reverse.")
            [:duration, 0.0],
            [:len, 0],
            [:error, 0.01])
-    make_env(:envelope, semitones_envelope(env, around, error), :scaler, scaler, :offset, offset,
+    make_env(:envelope, semitones_envelope(env, around, error),
+             :scaler, scaler, :offset, offset,
              :base, base, :duration, dur, :length, len)
   end
 
@@ -656,7 +739,8 @@ REFLECTED causes every other repetition to be in reverse.")
            [:duration, 0.0],
            [:len, 0],
            [:error, 0.01])
-    make_env(:envelope, octaves_envelope(env, around, error), :scaler, scaler, :offset, offset,
+    make_env(:envelope, octaves_envelope(env, around, error),
+             :scaler, scaler, :offset, offset,
              :base, base, :duration, dur, :length, len)
   end
 end
@@ -674,9 +758,11 @@ def test_power_env(start, dur, en)
 end
 
 with_sound(:channels, 1, :play, 1) do | |
-  test_power_env(0, 1, [0, 0, 0.325,   1, 1, 32,   2, 0, 0])
-  test_power_env(1.2, 1, [0, 0, 0.325,   1, 1, 32,   2, 0.5, 1,   3, 1, 0.1234,   4, 0, 0])
-  test_power_env(2.4, 1, [0, 0, 0,   1, 1, 1,   2, 0.5, 0.123,   3, 1, 321,   4, 0, 0])
+  test_power_env(0, 1, [0, 0, 0.325,  1, 1, 32,  2, 0, 0])
+  test_power_env(1.2, 1,
+                 [0, 0, 0.325,  1, 1, 32,  2, 0.5, 1,  3, 1, 0.1234,  4, 0, 0])
+  test_power_env(2.4, 1,
+                 [0, 0, 0,  1, 1, 1,  2, 0.5, 0.123,  3, 1, 321,  4, 0, 0])
 end
 =end
 
