@@ -597,7 +597,7 @@ static bool is_prompt_end(glistener *g, int end_pos)
 
 GtkWidget *glistener_text_widget(glistener *g) {return(g->text);}
 GtkTextBuffer *glistener_text_buffer(glistener *g) {return(g->buffer);}
-
+GtkWidget *glistener_status_widget(glistener *g) {return(g->status);}
 
 static void remember_listener_string(glistener *g, const char *str)
 {
@@ -2226,8 +2226,10 @@ static char *filename_completion(glistener *g, const char *partial_name)
       home = g_getenv("HOME");
       if (home)
 	{
-	  new_name = (char *)calloc(strlen(partial_name) + strlen(home) + 1, sizeof(char));
-	  strncpy(new_name, home, strlen(home));
+	  int len;
+	  len = strlen(home);
+	  new_name = (char *)calloc(strlen(partial_name) + len + 1, sizeof(char));
+	  strcat(new_name, home);
 	  strcat(new_name, (char *)(partial_name + 1));
 	}
     }
@@ -2316,7 +2318,7 @@ static char *filename_completion(glistener *g, const char *partial_name)
 	  /* attach matched portion to user's indication of dir */
 	  result = (char *)calloc(strlen(partial_name) + strlen(current_match) + 3, sizeof(char));
 	  temp = g_utf8_strrchr(partial_name, -1, (gunichar)'/');
-	  strncpy(result, partial_name, temp - partial_name + 1);
+	  memcpy(result, partial_name, temp - partial_name + 1);
 	  strcat(result, current_match);
 	  free(current_match);
 	}
