@@ -549,7 +549,7 @@ static void remake_edit_history(chan_info *cp)
   lst = EDIT_HISTORY_LIST(cp);
   if (!lst) return;
 
-  /* if you try to update something in a closed pane, goddamn gtk grinds to a halt */
+  /* if you try to update something in a closed pane, gtk grinds to a halt */
   if (gtk_paned_get_position(GTK_PANED(cp->widgets[W_main_window])) < 10) return;
 
   slist_clear(lst);
@@ -1540,8 +1540,8 @@ leaves the drawing area (graph pane) of the given channel."
   mouse_leave_graph_hook = Xen_define_hook(S_mouse_leave_graph_hook, "(make-hook 'snd 'chn)", 2, H_mouse_leave_graph_hook);
 
 #if HAVE_SCHEME
-  s7_symbol_set_setter(s7, ss->graph_cursor_symbol, s7_make_function(s7, "[acc-" S_graph_cursor "]", acc_graph_cursor, 2, 0, false, "accessor"));
-  s7_symbol_set_documentation(s7, ss->graph_cursor_symbol, "*graph-cursor*: current graph cursor shape");
+  s7_set_setter(s7, ss->graph_cursor_symbol, s7_make_function(s7, "[acc-" S_graph_cursor "]", acc_graph_cursor, 2, 0, false, "accessor"));
+  s7_set_documentation(s7, ss->graph_cursor_symbol, "*graph-cursor*: current graph cursor shape");
 #endif
 }
 
