@@ -13,7 +13,7 @@ static GtkAdjustment *baseAdj, *orderAdj;
 static gc_t *gc, *rgc, *ggc;
 static slist *env_list = NULL;
 #if (GTK_CHECK_VERSION(3, 89, 0))
-  static cairo_t *enved_cr;
+  static cairo_t *enved_cr = NULL;
 #endif
 
 static const char *env_names[3] = {"amp env:", "flt env:", "src env:"};
@@ -232,14 +232,14 @@ static void apply_enved(void)
 static void env_redisplay_1(printing_t printing)
 {
   cairo_t *cr;
-  bool clear_cr = false;
-
-  if (!enved_dialog_is_active()) return;
 #if (GTK_CHECK_VERSION(3, 89, 0))
+  if (!enved_dialog_is_active()) return;
   cr = enved_cr;
   if (!cr) return;
   ss->cr = cr; /* used in make_axes etc */
 #else
+  bool clear_cr = false;
+  if (!enved_dialog_is_active()) return;
   if ((printing == NOT_PRINTING) && 
       (!(ss->cr)))
     {
@@ -1339,7 +1339,8 @@ void set_enved_filter_order(int order)
       else {in_set_enved_filter_order(order);}
       if (enved_dialog)
 	{
-	  widget_int_to_text(enved_order_label, enved_filter_order(ss));
+	  /* widget_int_to_text(enved_order_label, enved_filter_order(ss)); */ /* this is a "spinbutton" now */
+	  gtk_spin_button_set_value(GTK_SPIN_BUTTON(enved_order_label), enved_filter_order(ss));
 	  if ((enved_target(ss) == ENVED_SPECTRUM) && 
 	      (enved_with_wave(ss)) && 
 	      (!showing_all_envs)) 
