@@ -34,15 +34,6 @@ static void add_help_text(GtkWidget *text, const char *message)
 
 int help_text_width(const char *txt, int start, int end)
 {
-#if 0
-  char *buf;
-  int len;
-  buf = (char *)calloc(end - start + 2, sizeof(char));
-  strncpy(buf, txt, end - start);
-  len = sg_text_width(buf, LISTENER_FONT(ss));
-  free(buf);
-  if (len > 0) return(len);
-#endif
   return((end - start) * 8);
 }
 
@@ -547,8 +538,9 @@ void save_find_dialog_state(FILE *fd)
 {
   if (find_dialog_is_active())
     {
-      char *text;
-      text = sg_get_text(edit_find_text, 0, -1);
+      const char *text;
+      /* text = sg_get_text(edit_find_text, 0, -1); -- this is for text_view widgets, but edit_find_text is a gtk_entry */
+      text = gtk_entry_get_text(GTK_ENTRY(edit_find_text));
 #if HAVE_SCHEME
       if (text)
 	fprintf(fd, "(%s #t \"%s\")\n", S_find_dialog, text);
@@ -579,7 +571,7 @@ void save_find_dialog_state(FILE *fd)
 	  else fprintf(fd, "#t %s drop\n", S_find_dialog);
 	}
 #endif
-      if (text) g_free(text);
+      /* if (text) g_free(text); */
     }
 }
 
