@@ -84,7 +84,11 @@ widget_t make_file_print_dialog(bool managed, bool direct_to_printer)
 
 static const char *ml[NUM_MENU_WIDGETS];
 
-void set_menu_label(GtkWidget *w, const char *label) {if (w) set_button_label(w, label);}
+void set_menu_label(GtkWidget *w, const char *label) 
+{
+  if (w) 
+    set_button_label(w, label);
+}
 
 
 
@@ -352,7 +356,7 @@ void check_menu_labels(int key, int state, bool extended) {}
 
 static void menu_drop_watcher(GtkWidget *w, const char *filename, int x, int y, void *data)
 {
-  snd_info *sp = NULL;
+  snd_info *sp;
   ss->open_requestor = FROM_DRAG_AND_DROP;
   sp = snd_open_file(filename, FILE_READ_WRITE);
   if (sp) select_channel(sp, 0);
@@ -976,7 +980,7 @@ void post_basic_popup_menu(void *e)
 #if GTK_CHECK_VERSION(3, 22, 0)
   gtk_menu_popup_at_pointer(GTK_MENU(basic_popup_menu), (const GdkEvent *)ev);
 #else
-  gtk_menu_popup(GTK_MENU(basic_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, EVENT_TIME(ev));
+  gtk_menu_popup(GTK_MENU(basic_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, event_time(ev));
 #endif
 }
 
@@ -1012,7 +1016,7 @@ static void popup_error_handler(const char *msg, void *data)
 static void popup_cut_to_new_callback_1(bool cut) 
 {
   char *temp_file;
-  io_error_t io_err = IO_NO_ERROR;
+  io_error_t io_err;
 
   temp_file = snd_tempnam();
   io_err = save_selection(temp_file, selection_srate(), default_output_sample_type(ss), default_output_header_type(ss), NULL, SAVE_ALL_CHANS);
@@ -1147,7 +1151,7 @@ void post_selection_popup_menu(void *e)
 #if GTK_CHECK_VERSION(3, 22, 0)
   gtk_menu_popup_at_pointer(GTK_MENU(selection_popup_menu), (const GdkEvent *)ev);
 #else
-  gtk_menu_popup(GTK_MENU(selection_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, EVENT_TIME(ev));
+  gtk_menu_popup(GTK_MENU(selection_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, event_time(ev));
 #endif
 }
 
@@ -1333,7 +1337,7 @@ void post_fft_popup_menu(void *e)
 #if GTK_CHECK_VERSION(3, 22, 0)
   gtk_menu_popup_at_pointer(GTK_MENU(fft_popup_menu), (const GdkEvent *)ev);
 #else
-  gtk_menu_popup(GTK_MENU(fft_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, EVENT_TIME(ev));
+  gtk_menu_popup(GTK_MENU(fft_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, event_time(ev));
 #endif
 }
 
@@ -1442,7 +1446,7 @@ static void full_dur_callback(GtkWidget *w, gpointer info)
   sp = any_selected_sound();
   if (sp)
     {
-      unsigned int i;
+      uint32_t i;
       for (i = 0; i < sp->nchans; i++)
 	set_x_axis_x0x1(sp->chans[i], 0.0, sp->chans[i]->axis->xmax);
     }
@@ -1455,7 +1459,7 @@ static void zoom_out_callback(GtkWidget *w, gpointer info)
   sp = any_selected_sound();
   if (sp)
     {
-      unsigned int i;
+      uint32_t i;
       for (i = 0; i < sp->nchans; i++)
 	zx_incremented(sp->chans[i], 2.0);
     }
@@ -1468,7 +1472,7 @@ static void zoom_in_callback(GtkWidget *w, gpointer info)
   sp = any_selected_sound();
   if (sp)
     {
-      unsigned int i;
+      uint32_t i;
       for (i = 0; i < sp->nchans; i++)
 	zx_incremented(sp->chans[i], 0.5);
     }
@@ -1481,7 +1485,7 @@ static void goto_start_callback(GtkWidget *w, gpointer info)
   sp = any_selected_sound();
   if (sp)
     {
-      unsigned int i;
+      uint32_t i;
       for (i = 0; i < sp->nchans; i++)
 	set_x_axis_x0x1(sp->chans[i], 0.0, sp->chans[i]->axis->x1 - sp->chans[i]->axis->x0);
     }
@@ -1493,7 +1497,7 @@ static void go_back_callback(GtkWidget *w, gpointer info)
   sp = any_selected_sound();
   if (sp)
     {
-      unsigned int i;
+      uint32_t i;
       for (i = 0; i < sp->nchans; i++)
 	sx_incremented(sp->chans[i], -1.0);
     }
@@ -1506,7 +1510,7 @@ static void go_forward_callback(GtkWidget *w, gpointer info)
   sp = any_selected_sound();
   if (sp)
     {
-      unsigned int i;
+      uint32_t i;
       for (i = 0; i < sp->nchans; i++)
 	sx_incremented(sp->chans[i], 1.0);
     }
@@ -1519,7 +1523,7 @@ static void goto_end_callback(GtkWidget *w, gpointer info)
   sp = any_selected_sound();
   if (sp)
     {
-      unsigned int i;
+      uint32_t i;
       for (i = 0; i < sp->nchans; i++)
 	set_x_axis_x0x1(sp->chans[i], sp->chans[i]->axis->xmax - sp->chans[i]->axis->x1 + sp->chans[i]->axis->x0, sp->chans[i]->axis->xmax);
     }
@@ -2006,12 +2010,12 @@ GtkWidget *menu_widget(int which_menu)
 {
   switch (which_menu)
     {
-    case FILE_MENU:    return(file_menu);           break;
-    case EDIT_MENU:    return(edit_menu);           break;
-    case VIEW_MENU:    return(view_menu);           break;
-    case OPTIONS_MENU: return(options_menu);        break;
-    case HELP_MENU:    return(help_menu);           break;
-    default:           return(added_menus[which_menu]); break;
+    case FILE_MENU:    return(file_menu);           
+    case EDIT_MENU:    return(edit_menu);           
+    case VIEW_MENU:    return(view_menu);           
+    case OPTIONS_MENU: return(options_menu);        
+    case HELP_MENU:    return(help_menu);           
+    default:           return(added_menus[which_menu]); 
     }
   return(NULL);
 }
@@ -2095,7 +2099,8 @@ int g_add_to_main_menu(const char *label, int slot)
   add_menu_style(mc);
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(m), mc);
   new_menu++;
-  added_menus[new_menu] = m; /* was mc -- 1-Mar-06 */
+  added_menus[new_menu] = m; /* was mc -- 1-Mar-06 */ /* returned by (main-menu new_menu) */
+  /* fprintf(stderr, "new: %d %p %d\n", new_menu, m, GTK_IS_MENU_ITEM(m)); */
   return(new_menu);
 }
 
