@@ -2415,7 +2415,7 @@ widget_t make_preferences_dialog(void)
     make_top_level_label("transform options", fft_box);
 
     rts_fft_size = transform_size(ss);
-    str = mus_format("%" PRId64, rts_fft_size);
+    str = mus_format("%" print_mus_long, rts_fft_size);
     prf = prefs_row_with_number("size", S_transform_size,
 				str, 12, 
 				fft_box,
