@@ -379,13 +379,13 @@ static int mix_selection(chan_info *cp, sync_info *si_out, mus_long_t beg, io_er
     {
       char *origin = NULL;
 #if HAVE_FORTH
-      origin = mus_format("%" PRId64 " snd chn %s", beg, S_mix_selection);
+      origin = mus_format("%" print_mus_long " snd chn %s", beg, S_mix_selection);
 #else
   #if HAVE_SCHEME
-      origin = mus_format("-mix-selection- %" PRId64 " %" PRId64 " %" PRId64 " snd chn",
+      origin = mus_format("-mix-selection- %" print_mus_long " %" print_mus_long " %" print_mus_long " snd chn",
                           beg, selection_beg(cp), selection_len());
   #else
-      origin = mus_format("%s" PROC_OPEN "%" PRId64, to_proc_name(S_mix_selection), beg);
+      origin = mus_format("%s" PROC_OPEN "%" print_mus_long, to_proc_name(S_mix_selection), beg);
   #endif
 #endif
       if (si_out->chans > 1)
@@ -461,9 +461,9 @@ static io_error_t insert_selection(chan_info *cp, sync_info *si_out, mus_long_t
 	      cp_in = si_in->cps[i];   /* selection chan to paste in (no wrap-around here) */
 	      len = cp_selection_len(cp_in, NULL);
 #if HAVE_FORTH
-	      origin = mus_format("%" PRId64 " %s", beg, S_insert_selection);
+	      origin = mus_format("%" print_mus_long " %s", beg, S_insert_selection);
 #else
-	      origin = mus_format("%s" PROC_OPEN "%" PRId64, to_proc_name(S_insert_selection), beg);
+	      origin = mus_format("%s" PROC_OPEN "%" print_mus_long, to_proc_name(S_insert_selection), beg);
 #endif
 	      if (file_insert_samples(beg, len,
 				      tempfile, cp_out, i,
@@ -908,23 +908,33 @@ static char *xen_selection_to_string(xen_selection *v)
   return(buf);
 }
 
-Xen_wrap_print(xen_selection, print_xen_selection, xen_selection_to_string)
-
 
 #if HAVE_FORTH || HAVE_RUBY
+Xen_wrap_print(xen_selection, print_xen_selection, xen_selection_to_string)
+
 static Xen g_xen_selection_to_string(Xen obj)
 {
   char *vstr;
   Xen result;
   #define S_xen_selection_to_string "selection->string"
-
   Xen_check_type(xen_is_selection(obj), obj, 1, S_xen_selection_to_string, "a selection");
-
   vstr = xen_selection_to_string(Xen_to_xen_selection(obj));
   result = C_string_to_Xen_string(vstr);
   free(vstr);
   return(result);
 }
+#else
+#if HAVE_SCHEME
+static s7_pointer g_xen_selection_to_string(s7_scheme *sc, s7_pointer args)
+{
+  char *vstr;
+  Xen result;
+  vstr = xen_selection_to_string(Xen_to_xen_selection(s7_car(args)));
+  result = C_string_to_Xen_string(vstr);
+  free(vstr);
+  return(result);
+}
+#endif
 #endif
 
 
@@ -967,7 +977,7 @@ static Xen g_selection(void)
 
 
 #if HAVE_SCHEME
-static Xen s7_xen_selection_length(s7_scheme *sc, Xen obj)
+static Xen s7_xen_selection_length(s7_scheme *sc, Xen args)
 {
   return(g_selection_framples(Xen_undefined, Xen_undefined));
 }
@@ -1039,12 +1049,12 @@ static void init_xen_selection(void)
 {
 #if HAVE_SCHEME
   xen_selection_tag = s7_make_c_type(s7, "<selection>");
-  s7_c_type_set_print(s7, xen_selection_tag, print_xen_selection);
   s7_c_type_set_free(s7, xen_selection_tag, free_xen_selection);
   s7_c_type_set_equal(s7, xen_selection_tag, s7_xen_selection_equalp);
   s7_c_type_set_length(s7, xen_selection_tag, s7_xen_selection_length);
   s7_c_type_set_copy(s7, xen_selection_tag, s7_xen_selection_copy);
   s7_c_type_set_fill(s7, xen_selection_tag, s7_xen_selection_fill);
+  s7_c_type_set_to_string(s7, xen_selection_tag, g_xen_selection_to_string);
 #else
 #if HAVE_RUBY
   xen_selection_tag = Xen_make_object_type("XenSelection", sizeof(xen_selection));
