@@ -187,7 +187,7 @@ char *just_directory(const char *name)
     if (name[i] == '/') 
       last_slash = i + 1;
   if (last_slash > 0)
-    strncpy(dirname, name, last_slash);
+    memcpy(dirname, name, last_slash);
   return(dirname);
 }
 
@@ -243,7 +243,7 @@ disk_space_t disk_has_space(mus_long_t bytes, const char *filename)
   kneeded = bytes >> 10;
   if (kfree < kneeded)
     {
-      snd_error("not enough space left on disk: only %" PRId64 " kbytes available", kfree);
+      snd_error("not enough space left on disk: only %" print_mus_long " kbytes available", kfree);
       return(NOT_ENOUGH_DISK_SPACE);
     }
   return(DISK_SPACE_OK);
