@@ -73,7 +73,7 @@
 (set! (*s7* 'max-vector-length) 10000)
 (set! (*s7* 'max-vector-dimensions) 10)
 (set! (*s7* 'autoloading?) #f)
-(set! (*s7* 'morally-equal-float-epsilon) 1.0e-6)
+(set! (*s7* 'equivalent-float-epsilon) 1.0e-6)
 (set! (current-output-port) #f)
 
 (define ostr "")
@@ -147,13 +147,13 @@
 (define (s7-history) (*s7* 'history))
 (define (s7-history-size) (*s7* 'history-size))
 
-(define (s7-set-morally-equal-float-epsilon x) (set! (*s7* 'morally-equal-float-epsilon) x))
+(define (s7-set-equivalent-float-epsilon x) (set! (*s7* 'equivalent-float-epsilon) x))
 (define (s7-set-hash-table-float-epsilon x) (set! (*s7* 'hash-table-float-epsilon) x))
 (define (s7-set-bignum-precision x) (set! (*s7* 'bignum-precision) x))
 (define (s7-set-float-format-precision x) (set! (*s7* 'float-format-precision) x))
 
 (define (s7-default-rationalize-error) (*s7* 'default-rationalize-error))
-(define (s7-morally-equal-float-epsilon) (*s7* 'morally-equal-float-epsilon))
+(define (s7-equivalent-float-epsilon) (*s7* 'equivalent-float-epsilon))
 (define (s7-hash-table-float-epsilon) (*s7* 'hash-table-float-epsilon))
 (define (s7-bignum-precision) (*s7* 'bignum-precision))
 (define (s7-float-format-precision) (*s7* 'float-format-precision))
@@ -178,7 +178,7 @@
        (eval code)))
 
 (define (checked-hash-table . args)
-  (let ((_h_ (make-hash-table (*s7* 'default-hash-table-length) morally-equal?)))
+  (let ((_h_ (make-hash-table (*s7* 'default-hash-table-length) equivalent?)))
     (do ((key/value args (cddr key/value)))
 	((null? key/value) _h_)
       (if (not (pair? (cdr key/value)))
@@ -186,7 +186,7 @@
 	  (set! (_h_ (car key/value)) (cadr key/value))))))
 
 (define (checked-hash-table . args)
-  (let ((_h_ (make-hash-table (*s7* 'default-hash-table-length) morally-equal?)))
+  (let ((_h_ (make-hash-table (*s7* 'default-hash-table-length) equivalent?)))
     (do ((key/value args (cdr key/value)))
 	((null? key/value) _h_)
       (if (not (pair? (car key/value)))
@@ -430,7 +430,7 @@
 			  ;'random-state->list 
 			  ;'pair-filename 
 			  ;'let-set! ;-- rootlet troubles?
-			  ;'coverlet ;-- blocks block's morally-equal?
+			  ;'coverlet ;-- blocks block's equivalent?
                           ;'help ;-- snd goes crazy
 			  ;'macroexpand ;-- uninteresting objstr stuff
 			  'signature ; -- circular lists cause infinite loops with (e.g.) for-each??
@@ -460,7 +460,7 @@
 			  'iterate 'float-vector? 
 			  'apply-values 'values
 			  'byte-vector-ref 'file-exists? 'make-int-vector 'string-downcase 'string-upcase 
-			  'byte-vector 'morally-equal? 
+			  'byte-vector 'equivalent? 
 			  'c-pointer? 'int-vector-ref
 			  'float? 
 			  'list-values 'byte-vector? 'openlet? 'iterator? 
@@ -484,7 +484,7 @@
 			  's7-set-stacktrace-defaults
 			  's7-set-gc-stats
 			  's7-set-default-rationalize-error
-			  's7-set-morally-equal-float-epsilon 
+			  's7-set-equivalent-float-epsilon 
 			  's7-set-hash-table-float-epsilon 
 			  's7-set-bignum-precision 
 			  's7-set-float-format-precision
@@ -500,7 +500,7 @@
 			  ;;'s7-history ;-- causes stack to grow?
 			  's7-print-length 's7-max-string-length 's7-max-list-length 's7-max-vector-length 's7-max-vector-dimensions 's7-default-hash-table-length
 			  's7-initial-string-port-length 's7-history-size
-			  's7-default-rationalize-error 's7-morally-equal-float-epsilon
+			  's7-default-rationalize-error 's7-equivalent-float-epsilon
 			  's7-hash-table-float-epsilon 's7-bignum-precision 
 			  's7-float-format-precision 
 			  ;'s7-default-random-state 
@@ -950,7 +950,7 @@
 	  (let ((val1 (car (list (eval-string str)))))
 	    (let ((newstr (object->string val1 :readable)))
 	      (let ((val2 (eval-string newstr)))
-		(if (not (morally-equal? val1 val2))
+		(if (not (equivalent? val1 val2))
 		    (format *stderr* "~%~S~%~S~%    ~W -> ~W~%" str newstr val1 val2))))))
 	(lambda arg 'error))
 
@@ -962,7 +962,7 @@
 	       (lambda (ok)
 		 (for-each
 		  (lambda (x y)
-		    (unless (and (morally-equal x y)
+		    (unless (and (equivalent x y)
 				 (not (gensym? x)))
 		      (format *stderr* "eval/string ~%~S~%    ~W -> ~W~%" str val1 val2)
 		      (ok)))
