@@ -3,6 +3,30 @@
 (define aux-counter 0)
 (system "make-repl")
 
+(let ((aux-file (format #f "t101-aux-~D.scm" (set! aux-counter (+ aux-counter 1)))))
+  (call-with-output-file aux-file
+    (lambda (p)
+      (format p "(set! (*s7* 'safety) 1)~%")
+      (format p "(load \"s7test.scm\")~%(exit)~%")))
+  (format *stderr* "~%~NC~%test: safety=1~%" 80 #\-)
+  (system (string-append "./repl " aux-file)))
+
+(let ((aux-file (format #f "t101-aux-~D.scm" (set! aux-counter (+ aux-counter 1)))))
+  (call-with-output-file aux-file
+    (lambda (p)
+      (format p "(set! (*s7* 'initial-string-port-length) 32)~%(set! (*s7* 'undefined-identifier-warnings) #t)~%(set! (*s7* 'hash-table-float-epsilon) 1e-3)~%")
+      (format p "(load \"s7test.scm\")~%(exit)~%")))
+  (format *stderr* "~%~NC~%test: port-length=32 etc~%" 80 #\-)
+  (system (string-append "./repl " aux-file)))
+
+(let ((aux-file (format #f "t101-aux-~D.scm" (set! aux-counter (+ aux-counter 1)))))
+  (call-with-output-file aux-file
+    (lambda (p)
+      (format p "(with-input-from-file \"all-lg-results\" (lambda () (display (with-output-to-string (lambda () (load \"s7test.scm\")))) (newline)))")
+      (format p "(load \"s7test.scm\")~%(exit)~%")))
+  (format *stderr* "~%~NC~%test: stdin from all-lg-results~%" 80 #\-)
+  (system (string-append "./repl " aux-file)))
+
 (for-each
  (lambda (test-case)
    (let ((aux-file (format #f "t101-aux-~D.scm" (set! aux-counter (+ aux-counter 1)))))
@@ -116,8 +140,8 @@
       clauses)
      (values))))
 
-(format *stderr* "~%~NC local s7test ~NC~%" 20 #\- 20 #\-)
-(system "./snd -e '(let () (catch #t (lambda () (load \"s7test.scm\" (curlet))) (lambda args #f)) (exit))'")
+;(format *stderr* "~%~NC local s7test ~NC~%" 20 #\- 20 #\-)
+;(system "./snd -e '(let () (catch #t (lambda () (load \"s7test.scm\" (curlet))) (lambda args #f)) (exit))'")
 
 (format *stderr* "~NC s7test ~NC~%" 20 #\- 20 #\-)
 (system "./repl s7test.scm")
@@ -152,6 +176,9 @@
 (format *stderr* "~NC tauto ~NC~%" 20 #\- 20 #\-)
 (system "./repl tauto.scm")
 
+;(format *stderr* "~NC mauto ~NC~%" 20 #\- 20 #\-)
+;(system "./repl mauto.scm")
+
 (format *stderr* "~NC tset ~NC~%" 20 #\- 20 #\-)
 (system "./repl tset.scm")
 
