@@ -230,11 +230,11 @@
 	(test (string=? big1 bigstr) #t)
 	(test (string>? big1 bigstr) #f)
 					;(test (string-ci<=? big1 bigstr) #t)
-	(test (morally-equal? big1 bigstr) #t)
+	(test (equivalent? big1 bigstr) #t)
 	(set! (big1 (- big-size 1)) #\f)
 	(test (equal? big1 bigstr) #f)
 	(test (string=? big1 bigstr) #f)
-	(test (morally-equal? big1 bigstr) #f)
+	(test (equivalent? big1 bigstr) #f)
 	(let ((big2 (substring big1 (- (ash 1 31) 10) (+ (ash 1 31) 10))))
 	  (test big2 "dddddddddddddddddddd")
 	  (test (length big2) 20)
@@ -400,15 +400,15 @@
   (let ((bigfv (make-float-vector big-size 0.5)))
     (let-temporarily (((*s7* 'print-length) 100))
       (let ((big1 (copy bigfv)))
-	(test (morally-equal? big1 bigfv) #t)
+	(test (equivalent? big1 bigfv) #t)
 	(set! (big1 (- big-size 1)) 0.25)
-	(test (morally-equal? big1 bigfv) #f)
+	(test (equivalent? big1 bigfv) #f)
 	(let ((big2 (subvector big1 20 (- (ash 1 31) 10))))
 	  (test big2 (make-float-vector 20 0.5))
 	  (test (length big2) 20)
 	  (let ((big3 (make-float-vector 20 0.0)))
 	    (copy bigfv big3 (- (ash 1 31) 10) (+ (ash 1 31) 10))
-	    (test (morally-equal? big2 big3) #t)))))
+	    (test (equivalent? big2 big3) #t)))))
 
     (define (big-float-vector-filler)
       (do ((i 0 (+ i 1)))
@@ -454,7 +454,7 @@
 	    (float-vector-set! str i (float-vector-ref (make-float-vector (+ 1 (random 200)) j) 0))
 	    (float-vector-set! str1 i j)))
 	(float-vector-writer)
-	(test (morally-equal? str str1) #t)))))
+	(test (equivalent? str str1) #t)))))
 
 (when (> total-memory (* 16 big-size))
   (format () "test 3~%")
@@ -745,15 +745,15 @@
   (let ((bigfv (make-int-vector big-size 5)))
     (let-temporarily (((*s7* 'print-length) 100))
       (let ((big1 (copy bigfv)))
-	(test (morally-equal? big1 bigfv) #t)
+	(test (equivalent? big1 bigfv) #t)
 	(set! (big1 (- big-size 1)) 25)
-	(test (morally-equal? big1 bigfv) #f)
+	(test (equivalent? big1 bigfv) #f)
 	(let ((big2 (subvector big1 20 (- (ash 1 31) 10))))
 	  (test big2 (make-int-vector 20 5))
 	  (test (length big2) 20)
 	  (let ((big3 (make-int-vector 20 0)))
 	    (copy bigfv big3 (- (ash 1 31) 10) (+ (ash 1 31) 10))
-	    (test (morally-equal? big2 big3) #t)))))
+	    (test (equivalent? big2 big3) #t)))))
     (define (big-int-vector-filler)
       (do ((i 0 (+ i 1)))
 	  ((= i big-size))
@@ -799,7 +799,7 @@
 	    (int-vector-set! str i (int-vector-ref (make-int-vector (+ 1 (random 200)) j) 0))
 	    (int-vector-set! str1 i j)))
 	(int-vector-writer)
-	(test (morally-equal? str str1) #t)))))
+	(test (equivalent? str str1) #t)))))
 (clear-and-gc)
 
 (when (> total-memory (* 16 big-size))
@@ -833,7 +833,6 @@
     (test (bigfv (ash 1 31)) 3))
   (clear-and-gc))
 
-
 (define (int-vector-fft rl im n dir)
   (when rl
     (let ((tempr 0.0)
@@ -1070,7 +1069,6 @@
 (vector-test)
 (clear-and-gc)
 
-
 (define (vector-2d-fft rl n dir)
   (when rl
     (let ((tempr 0.0)
@@ -1087,16 +1085,18 @@
 	  (mmax 2)
 	  (pw (/ n 2))
 	  (end 0)
-	  (theta (* pi dir)))
+	  (theta (* pi dir))
+	  (rl0 (subvector rl fft-size))
+	  (rl1 (subvector rl fft-size fft-size)))
       (do ((i 0 (+ i 1)))
 	  ((= i n))
 	(when (> j i)
-	  (set! tempr (vector-ref rl 0 j))
-	  (set! tempi (vector-ref rl 1 j))
-	  (vector-set! rl 0 j (vector-ref rl 0 i))
-	  (vector-set! rl 1 j (vector-ref rl 1 i))
-	  (vector-set! rl 0 i tempr)
-	  (vector-set! rl 1 i tempi))
+	  (set! tempr (vector-ref rl0 j))
+	  (set! tempi (vector-ref rl1 j))
+	  (vector-set! rl0 j (vector-ref rl0 i))
+	  (vector-set! rl1 j (vector-ref rl1 i))
+	  (vector-set! rl0 i tempr)
+	  (vector-set! rl1 i tempi))
 	(set! m (quotient n 2))
 	(do () 
 	    ((not (<= 2 m j)))
@@ -1116,12 +1116,12 @@
 	  (set! end (+ ii (* pw mmax)))
 	  (do ((i ii (+ i mmax)))
 	      ((= i end))
-	    (set! tempr (- (* wr (vector-ref rl 0 j)) (* wi (vector-ref rl 1 j))))
-	    (set! tempi (+ (* wr (vector-ref rl 1 j)) (* wi (vector-ref rl 0 j))))
-	    (vector-set! rl 0 j (- (vector-ref rl 0 i) tempr))
-	    (vector-set! rl 0 i (+ (vector-ref rl 0 i) tempr))
-	    (vector-set! rl 1 j (- (vector-ref rl 1 i) tempi))
-	    (vector-set! rl 1 i (+ (vector-ref rl 1 i) tempi))
+	    (set! tempr (- (* wr (vector-ref rl0 j)) (* wi (vector-ref rl1 j))))
+	    (set! tempi (+ (* wr (vector-ref rl1 j)) (* wi (vector-ref rl0 j))))
+	    (vector-set! rl0 j (- (vector-ref rl0 i) tempr))
+	    (vector-set! rl0 i (+ (vector-ref rl0 i) tempr))
+	    (vector-set! rl1 j (- (vector-ref rl1 i) tempi))
+	    (vector-set! rl1 i (+ (vector-ref rl1 i) tempi))
 	    (set! j (+ j mmax)))
 	  (set! wtemp wr)
 	  (set! wr (- (* wr wpr) (* wi wpi)))
@@ -1174,6 +1174,7 @@
 (vector-2d-test 2)
 (clear-and-gc)
 
+
 ;; --------------------------------------------------------------------------------
 (format () "~%blocks...~%")
 
@@ -1215,7 +1216,10 @@
 	  (set! m (/ m 2)))
 	(set! j (+ j m))))
     (let ((ipow (floor (log n 2)))
-	  (prev 1))
+	  (prev 1)
+	  (tempr 0.0)
+	  (tempi 0.0)
+	  (wtemp 0.0))
       (do ((mmax 2 (* mmax 2))
 	   (pow (/ n 2) (/ pow 2))
 	   (theta (* pi dir) (* theta 0.5))
@@ -1231,15 +1235,15 @@
 		 (j (+ ii prev) (+ j mmax))
 		 (jj 0 (+ jj 1)))
 		((>= jj pow))
-	      (let ((tempr (- (* wr (rl j)) (* wi (im j))))
-		    (tempi (+ (* wr (im j)) (* wi (rl j)))))
-		(set! (rl j) (- (rl i) tempr))
-		(set! (rl i) (+ (rl i) tempr))
-		(set! (im j) (- (im i) tempi))
-		(set! (im i) (+ (im i) tempi))))
-	    (let ((wtemp wr))
-	      (set! wr (- (* wr wpr) (* wi wpi)))
-	      (set! wi (+ (* wi wpr) (* wtemp wpi)))))
+	      (set! tempr (- (* wr (rl j)) (* wi (im j))))
+	      (set! tempi (+ (* wr (im j)) (* wi (rl j))))
+	      (set! (rl j) (- (rl i) tempr))
+	      (set! (rl i) (+ (rl i) tempr))
+	      (set! (im j) (- (im i) tempi))
+	      (set! (im i) (+ (im i) tempi)))
+	    (set! wtemp wr)
+	    (set! wr (- (* wr wpr) (* wi wpi)))
+	    (set! wi (+ (* wi wpr) (* wtemp wpi))))
 	  (set! prev mmax))))
     rl))
 
@@ -1291,16 +1295,18 @@
 	  (mmax 2)
 	  (pw (/ n 2))
 	  (end 0)
-	  (theta (* pi dir)))
+	  (theta (* pi dir))
+	  (tempbr #f)
+	  (tempbi #f))
       (do ((i 0 (+ i 1)))
 	  ((= i n))
 	(when (> j i)
-	  (set! tempr (vector-ref rl j))
-	  (set! tempi (vector-ref im j))
+	  (set! tempbr (vector-ref rl j))
+	  (set! tempbi (vector-ref im j))
 	  (vector-set! rl j (vector-ref rl i))
 	  (vector-set! im j (vector-ref im i))
-	  (vector-set! rl i tempr)
-	  (vector-set! im i tempi))
+	  (vector-set! rl i tempbr)
+	  (vector-set! im i tempbi))
 	(set! m (quotient n 2))
 	(do () 
 	    ((not (<= 2 m j)))
@@ -1380,7 +1386,6 @@
 (clear-and-gc)
 
 
-
 ;; --------------------------------------------------------------------------------
 ;; hash-tables round up to the next power of 2
 
@@ -1442,27 +1447,30 @@
 	(let ((wpr (cos theta))
 	      (wpi (sin theta))
 	      (wr 1.0)
-	      (wi 0.0))
+	      (wi 0.0)
+	      (wtemp 0.0)
+	      (tempr 0.0)
+	      (tempi 0.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
 	    (do ((i ii (+ i mmax))
 		 (j (+ ii prev) (+ j mmax))
 		 (jj 0 (+ jj 1)))
 		((>= jj pow))
-	      (let ((tempr (- (* wr (hash-table-ref rl j)) (* wi (hash-table-ref im j))))
-		    (tempi (+ (* wr (hash-table-ref im j)) (* wi (hash-table-ref rl j)))))
-		(hash-table-set! rl j (- (hash-table-ref rl i) tempr))
-		(hash-table-set! rl i (+ (hash-table-ref rl i) tempr))
-		(hash-table-set! im j (- (hash-table-ref im i) tempi))
-		(hash-table-set! im i (+ (hash-table-ref im i) tempi))))
-	    (let ((wtemp wr))
-	      (set! wr (- (* wr wpr) (* wi wpi)))
-	      (set! wi (+ (* wi wpr) (* wtemp wpi)))))
+	      (set! tempr (- (* wr (hash-table-ref rl j)) (* wi (hash-table-ref im j))))
+	      (set! tempi (+ (* wr (hash-table-ref im j)) (* wi (hash-table-ref rl j))))
+	      (hash-table-set! rl j (- (hash-table-ref rl i) tempr))
+	      (hash-table-set! rl i (+ (hash-table-ref rl i) tempr))
+	      (hash-table-set! im j (- (hash-table-ref im i) tempi))
+	      (hash-table-set! im i (+ (hash-table-ref im i) tempi)))
+	    (set! wtemp wr)
+	    (set! wr (- (* wr wpr) (* wi wpi)))
+	    (set! wi (+ (* wi wpr) (* wtemp wpi))))
 	  (set! prev mmax))))
     rl))
 
 (define (hash-test)
-  (let ((fvr (make-hash-table fft-size))
+  (let ((fvr (make-hash-table fft-size)) ; (make-hash-table fft-size #t (cons #t float?))
 	(fvi (make-hash-table fft-size))
 	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
@@ -2170,16 +2178,18 @@
 	  (mmax 2)
 	  (pw (/ n 2))
 	  (end 0)
-	  (theta (* pi dir)))
+	  (theta (* pi dir))
+	  (tempbr #f)
+	  (tempbi #f))
       (do ((i 0 (+ i 1)))
 	  ((= i n))
 	(when (> j i)
-	  (set! tempr (vector-ref rl j))
-	  (set! tempi (vector-ref im j))
+	  (set! tempbr (vector-ref rl j))
+	  (set! tempbi (vector-ref im j))
 	  (vector-set! rl j (vector-ref rl i))
 	  (vector-set! im j (vector-ref im i))
-	  (vector-set! rl i tempr)
-	  (vector-set! im i tempi))
+	  (vector-set! rl i tempbr)
+	  (vector-set! im i tempbi))
 	(set! m (quotient n 2))
 	(do () 
 	    ((not (<= 2 m j)))
