@@ -57,10 +57,9 @@
       (f1 1 2)
       (f1 y x)
       (f1 1)
+      (f1 :a 1)
       (f1)
       (f1 (- y 1))
-      (f1 :b 2)
-      (f1 :a 1 :b 2)
       (f2) (f2)
       (f2 1)
       (f2 :a 1)
@@ -73,9 +72,8 @@
       (f6 1 2 3)
       (f6 1 2)
       (f6 1)
+      (f6 :a 1)
       (f6)
-      (f6 :b (list 2) :a 1)
-      (f6 :b (list 2))
       (f7 1 2)
       (f7 1)
       (f7)
@@ -85,7 +83,7 @@
       (f9)
       (f9 1 x y)
       (f10)
-      (f10 :a 2 :b 1)
+      (f10 :a 2 :b 2)
       (f11)
       (f11 x)
       (f11 x y))))
