@@ -2,13 +2,15 @@
   ;; depends on running s7test first normally
   (load "s7test-block.so" new-env))
 
+(set! (*s7* 'heap-size) 1024000)
+
 (define (test-copy size)
   (let ((old-string (make-string size #\a))
 	(old-bvect (make-byte-vector size 1))
 	(old-pair (make-list size #\a))
-	(old-vector (make-vector size #\a))
-	(old-vectorf (make-vector size 1.0))
-	(old-vectori (make-vector size 1))
+	(old-vector (make-vector size #\a char?))
+	(old-vectorf (make-vector size 1.0 real?))
+	(old-vectori (make-vector size 1 integer?))
 	(old-fvect (make-float-vector size 1.0))
 	(old-ivect (make-int-vector size 1))
 	(old-hash (make-hash-table size))
@@ -221,7 +223,7 @@
 	  (ifvec (apply vector-append ifvecs))
 	  (allvec (apply vector-append allvecs))
 	  (str (apply string-append strs))
-	  (bvec (string->byte-vector (apply string-append bvecs))))
+	  (bvec (apply vector-append bvecs)))
       (test (vector? vec) #t)
       (test (length vec) (* size size))
       (test (float-vector? fvec) #t)
@@ -242,7 +244,6 @@
       (test (length bvec) (* size size))
       )))
       
-
 (define (t)
   (do ((i 0 (+ i 1)))
       ((= i 10000))
