@@ -13,13 +13,6 @@
 (define mock-symbol (*mock-symbol* 'mock-symbol))
 (define mock-hash-table (*mock-hash-table* 'mock-hash-table))
 
-(define np (list 0 1 2 3 4))
-(define mp (mock-pair '(0 1 2 3 4)))
-(define nv (vector 0 1 2 3 4))
-(define mv (mock-vector 0 1 2 3 4))
-(define ns "01234")
-(define ms (mock-string #\0 #\1 #\2 #\3 #\4))
-
 ;;(openlet (inlet 'i 0 'list-set! (lambda (l . args) (apply #_list-set! l ((car args) 'i) (cdr args))))))
 
 (define-constant constants (vector #f #t () #\a (/ most-positive-fixnum) (/ -1 most-positive-fixnum) 1.5+i 
@@ -49,7 +42,7 @@
 			  (open-input-string "123123") (open-input-file "/home/bil/cl/4.aiff")
 			  (open-output-file "test.test") (open-output-string)
 			  
-			  (mock-number 0) (mock-number 2) (mock-number 1-i) (mock-number 4/3) (mock-number 2.0)
+			  ;(mock-number 0) (mock-number 2) (mock-number 1-i) (mock-number 4/3) (mock-number 2.0)
 			  (mock-string #\h #\o #\h #\o)
 			  (mock-pair '(2 3 4))
 			  (mock-char #\b)
@@ -72,47 +65,49 @@
 		    ))
 (define-constant ctrl-chars-len (length ctrl-chars))
 
+(define (test-calls ctrl-str tries size1 op)
+  (let ((x #f) (y #f) (z #f) (pos 0)
+	(cs constants)
+	(cs-len constants-len))
+    (do ((i 0 (+ i 1)))
+	((= i tries))
+      (do ((j 1 (+ j 1)))
+	  ((= j size1))
+	(string-set! ctrl-str j (string-ref ctrl-chars (random ctrl-chars-len))))
+      
+      (set! x (cs (random cs-len)))
+      (set! y (cs (random cs-len)))
+      (set! z (cs (random cs-len)))
+      
+      (object->string x)
+      (display x op)
+      
+      (catch #t (lambda () (format #f "~{~^~S ~} ~{~|~S ~} ~W" x y z)) (lambda arg 'error))
+      (catch #t (lambda () (format #f ctrl-str)) (lambda arg 'error))
+      (catch #t (lambda () (format #f ctrl-str x)) (lambda arg 'error))
+      (catch #t (lambda () (format #f ctrl-str y)) (lambda arg 'error))
+      (catch #t (lambda () (format #f ctrl-str z)) (lambda arg 'error))
+      (set! pos (char-position #\~ ctrl-str 1))
+      (when pos
+	(catch #t (lambda () (format #f ctrl-str x z)) (lambda arg 'error))
+	(catch #t (lambda () (format #f ctrl-str x y)) (lambda arg 'error))
+	(catch #t (lambda () (format #f ctrl-str y z)) (lambda arg 'error))
+	(catch #t (lambda () (format #f ctrl-str z x)) (lambda arg 'error))
+	(when (char-position #\~ ctrl-str (+ pos 1))
+	  (catch #t (lambda () (format #f ctrl-str x y z)) (lambda arg 'error))
+	  (catch #t (lambda () (format #f ctrl-str z y x)) (lambda arg 'error)))))))
+
 (define (test-chars)
-  (let ((op (open-output-string))
-	(x #f) (y #f) (z #f))
+  (let ((op (open-output-string)))
     (do ((size 2 (+ size 1))
 	 (size1 3 (+ size1 1))
 	 (tries 4000 (+ tries 2000))
-	 (pos 0)
-	 (cs constants)
-	 (cs-len constants-len)
 	 (ctrl-str (make-string 16 #\space)))
 	((= size 15))
       (format *stderr* "~D " size)
       (string-set! ctrl-str size1 #\null)
       (string-set! ctrl-str 0 #\~)
-      (do ((i 0 (+ i 1)))
-	  ((= i tries))
-	(do ((j 1 (+ j 1)))
-	    ((= j size1))
-	  (string-set! ctrl-str j (string-ref ctrl-chars (random ctrl-chars-len))))
-	
-	(set! x (cs (random cs-len)))
-	(set! y (cs (random cs-len)))
-	(set! z (cs (random cs-len)))
-	
-	(object->string x)
-	(display x op)
-	
-	(catch #t (lambda () (format #f "~{~^~S ~} ~{~|~S ~} ~W" x y z)) (lambda arg 'error))
-	(catch #t (lambda () (format #f ctrl-str)) (lambda arg 'error))
-	(catch #t (lambda () (format #f ctrl-str x)) (lambda arg 'error))
-	(catch #t (lambda () (format #f ctrl-str y)) (lambda arg 'error))
-	(catch #t (lambda () (format #f ctrl-str z)) (lambda arg 'error))
-	(set! pos (char-position #\~ ctrl-str 1))
-	(when pos
-	  (catch #t (lambda () (format #f ctrl-str x z)) (lambda arg 'error))
-	  (catch #t (lambda () (format #f ctrl-str x y)) (lambda arg 'error))
-	  (catch #t (lambda () (format #f ctrl-str y z)) (lambda arg 'error))
-	  (catch #t (lambda () (format #f ctrl-str z x)) (lambda arg 'error))
-	  (when (char-position #\~ ctrl-str (+ pos 1))
-	    (catch #t (lambda () (format #f ctrl-str x y z)) (lambda arg 'error))
-	    (catch #t (lambda () (format #f ctrl-str z y x)) (lambda arg 'error)))))
+      (test-calls ctrl-str tries size1 op)
       (get-output-string op #t))
     (close-output-port op)))
 
