@@ -1,34 +1,43 @@
-(set! (*s7* 'heap-size) 1024000)
+(set! (*s7* 'heap-size) (* 6 1024000))
 ;(set! (*s7* 'gc-stats) 6)
-;heap ca 30*size!
 
 (define (reader)
   (let ((port (open-input-file "/home/bil/test/scheme/bench/src/bib"))
-	(new-pos 0)
-	(counts (make-hash-table)))
+	(counts (make-hash-table))
+	(start 0)
+	(end 0)
+	(new-pos 0))
     (do ((line (read-line port) (read-line port)))
 	((eof-object? line))
       (set! new-pos 0)
       (do ((pos (char-position #\space line) (char-position #\space line (+ pos 1))))
 	  ((not pos))
 	(unless (= pos new-pos)
-	  (let* ((start (do ((k new-pos (+ k 1))) ; char-position here is slower!
-			    ((or (char-alphabetic? (string-ref line k))
-				 (= k pos))
-			     k)))
-		 (end (do ((k (- pos 1) (- k 1)))
-			  ((or (char-alphabetic? (string-ref line k))
-			       (= k start))
-			   (+ k 1)))))
-	    (when (> end start)
-	      (let ((word (string->symbol (substring line start end))))
-		(let ((refs (or (hash-table-ref counts word) 0)))
-		  (hash-table-set! counts word (+ refs 1)))))))
+	  (set! start 
+		(if (char-alphabetic? (string-ref line new-pos))
+		    new-pos
+		    (do ((k (+ new-pos 1) (+ k 1))) ; char-position here is slower!
+			((or (char-alphabetic? (string-ref line k))
+			     (>= k pos))
+			 k))))
+	  (set! end 
+		(if (char-alphabetic? (string-ref line (- pos 1)))
+		    pos
+		    (do ((k (- pos 2) (- k 1)))
+			((or (char-alphabetic? (string-ref line k))
+			     (<= k start))
+			 (+ k 1)))))
+	  (when (> end start)
+	    (let ((word (string->symbol (substring line start end))))
+	      (let ((refs (or (hash-table-ref counts word) 0)))
+		(hash-table-set! counts word (+ refs 1))))))
 	(set! new-pos (+ pos 1))))
     
     (close-input-port port)
-    (sort! (copy counts (make-vector (hash-table-entries counts)))
-	   (lambda (a b) (> (cdr a) (cdr b))))))
+    (let ((res (sort! (copy counts (make-vector (hash-table-entries counts)))
+		      (lambda (a b) (> (cdr a) (cdr b))))))
+      (set! counts #f)
+      res)))
 
 (format *stderr* "reader ")
 
@@ -68,7 +77,8 @@
     (do ((i 0 (+ i 1)))	
 	((= i size))
       (if (not (= (hash-table-ref int-hash i) i))
-	  (display "oops")))))
+	  (display "oops")))
+    (set! int-hash #f)))
 
 (define (test3 size)
   (let ((flt-hash (make-hash-table size)))
@@ -78,7 +88,8 @@
     (do ((i 0 (+ i 1)))	
 	((= i size))
       (if (not (= (hash-table-ref flt-hash (* 2.0 i)) i))
-	  (display "oops")))))
+	  (display "oops")))
+    (set! flt-hash #f)))
 
 (define (test4 size)
   (let ((sym-hash (make-hash-table size)))
@@ -88,7 +99,8 @@
     (do ((i 0 (+ i 1))) 
 	((= i size)) 
       (if (not (= (hash-table-ref sym-hash (vector-ref symbols i)) i)) 
-	  (display "oops")))))
+	  (display "oops")))
+    (set! sym-hash #f)))
 
 (define (test5 size)
   (let ((str-hash (make-hash-table size eq?)))
@@ -98,7 +110,8 @@
     (do ((i 0 (+ i 1))) 
 	((= i size)) 
       (if (not (= (hash-table-ref str-hash (vector-ref strings i)) i)) 
-	  (display "oops")))))
+	  (display "oops")))
+    (set! str-hash #f)))
 
 (define (test6 size)
   (let ((sym-hash (make-hash-table size eq?)))
@@ -108,7 +121,8 @@
     (do ((i 0 (+ i 1))) 
 	((= i size)) 
       (if (not (= (hash-table-ref sym-hash (vector-ref symbols i)) i)) 
-	  (display "oops")))))
+	  (display "oops")))
+    (set! sym-hash #f)))
 
 (define (test7 size)
   (let ((chr-hash (make-hash-table 256)))
@@ -118,7 +132,8 @@
     (do ((i 0 (+ i 1))) 
 	((= i 256)) 
       (if (not (= (hash-table-ref chr-hash (integer->char i)) i))
-	  (display "oops")))))
+	  (display "oops")))
+    (set! chr-hash #f)))
 
 (define (test8 size)
   (let ((any-hash (make-hash-table size eq?)))
@@ -132,7 +147,8 @@
     (do ((i 0 (+ i 1))) 
 	((= i size)) 
       (if (not (= i (hash-table-ref any-hash (vector-ref strings i))))
-	  (display "oops")))))
+	  (display "oops")))
+    (set! any-hash #f)))
 
 (define (test9 size)
   (let ((any-hash1 (make-hash-table size eq?)))
@@ -148,7 +164,8 @@
 	((= i size)) 
       (if (not (= i (hash-table-ref any-hash1 (vector-ref strings i))))
 	  (display "oops")))
-    (vector-fill! strings #f)))
+    (vector-fill! strings #f)
+    (set! any-hash1 #f)))
 
 (define (test10 size)
   (let ((cmp-hash (make-hash-table size)))
@@ -158,7 +175,8 @@
     (do ((i 0 (+ i 1))) 
 	((= i size)) 
       (if (not (= (hash-table-ref cmp-hash (complex i i)) i)) 
-	  (display "oops")))))
+	  (display "oops")))
+    (set! cmp-hash #f)))
 
 (define (test-hash size)
   (format *stderr* "~D " size)
@@ -177,23 +195,6 @@
 
 (for-each test-hash (list 1 10 100 1000 10000 100000 1000000))
 (newline)
-;(gc)
-
-#|
-(load "write.scm")
-(for-each (lambda (func)
-	    (let ((source (procedure-source func)))
-	      (let walker ((tree source))
-		(when (pair? tree)
-		  (if (symbol? (car tree))
-		      (if (local-symbol? tree)
-			  (set-car! tree (symbol "[" (symbol->string (car tree)) "]")))
-		      (walker (car tree)))
-		  (walker (cdr tree))))
-	      (pretty-print source))
-	    (newline))
-	  (list reader test1 test2 test3 test4 test5 test6 test7 test8 test9 test10))
-|#
 
 (s7-version)
 (exit)
