@@ -147,9 +147,83 @@
 
 ;;; --------------------------------------------------------------------------------
 
+;;; this one is not very good (unsafe non-tc recursion is slow)
 
+(define binary-tree
+  (let ((new-tree-node cons))
+
+    (define (item-check tree)
+      (if (car tree)
+	  (+ 1 (item-check (car tree)) (item-check (cdr tree)))
+	  1))
+    
+    (define (bottom-up-tree depth)
+      (if (zero? depth)
+	  (new-tree-node #f #f)
+	  (new-tree-node (bottom-up-tree (- depth 1)) 
+			 (bottom-up-tree (- depth 1)))))
+    
+    (lambda (N)
+      (let* ((min-depth 4)
+	     (max-depth (if (> (+ min-depth 2) N) (+ min-depth 2) N))
+	     (stretch-depth (+ max-depth 1))
+	     (stretch-tree (bottom-up-tree stretch-depth)))
+	(format *stderr* "stretch tree of depth ~D~30Tcheck: ~D~%" stretch-depth (item-check stretch-tree))
+	(let ((long-lived-tree (bottom-up-tree max-depth)))
+	  (do ((depth min-depth (+ depth 2)))
+	      ((> depth max-depth))
+	    (let ((iterations (expt 2 (+ max-depth (- depth) min-depth))))
+	      (do ((i 0 (+ i 1))
+		   (check 0 (+ check (item-check (bottom-up-tree depth)))))
+		  ((= i iterations)
+		   (format *stderr* "~D~9Ttrees of depth ~D~30Tcheck: ~D~%" iterations depth check)))))
+	  (format *stderr* "long lived tree of depth ~D~30Tcheck: ~D~%" max-depth (item-check long-lived-tree)))))))
+
+;(binary-tree 21) ; 84.4 secs if (set! (*s7* 'heap-size) (* 36 1024000))
+
+"
+stretch tree of depth 22	 check: 8388607
+2097152	 trees of depth 4	 check: 65011712
+524288	 trees of depth 6	 check: 66584576
+131072	 trees of depth 8	 check: 66977792
+32768	 trees of depth 10	 check: 67076096
+8192	 trees of depth 12	 check: 67100672
+2048	 trees of depth 14	 check: 67106816
+512	 trees of depth 16	 check: 67108352
+128	 trees of depth 18	 check: 67108736
+32	 trees of depth 20	 check: 67108832
+long lived tree of depth 21	 check: 4194303
+"
 
 ;;; --------------------------------------------------------------------------------
 
+(define collatz
+  (let ()
+    (define (collatz-count-until-1 n)
+      (do ((count 0 (+ count 1)))
+	  ((= n 1)
+	   count)
+	(if (logbit? n 0)
+	    (set! n (+ (* 3 n) 1))
+	    (set! n (ash n -1)))))
+    (lambda ()
+      (let ((len 0)
+	    (num 0)
+	    (cur 0))
+	(do ((i 1 (+ i 1)))
+	    ((= i 300000))
+	  (set! cur (collatz-count-until-1 i))
+	  (when (< len cur)
+	    (set! len cur)
+	    (set! num i)))
+	(format *stderr* "Maximum stopping distance ~D, starting number ~D\n" len num)))))
+
+;(collatz)
+;; Maximum stopping distance 442, starting number 230631
+;; .66 secs
+
+;;; --------------------------------------------------------------------------------
+
+
 (s7-version)
 (exit)
